@@ -1,7 +1,9 @@
 package mapper
 
 import (
+	"crypto/sha1"
 	"fmt"
+	"math"
 	"strings"
 
 	oos "github.com/kubevirt/vm-import-operator/pkg/providers/ovirt/os"
@@ -277,8 +279,9 @@ func (o *OvirtMapper) MapDataVolumes(targetVMName *string, filesystemOverhead cd
 		diskSize, _ := disk.ProvisionedSize()
 		overhead := utils.GetOverheadForStorageClass(filesystemOverhead, sdClass)
 
-		blockSize := int64(512)
-		sizeWithOverhead := utils.RoundUp(int64(float64(diskSize)/(1-overhead)), blockSize)
+		blockSize := int64(1048576)
+		alignedSize := utils.RoundUp(diskSize, blockSize)
+		sizeWithOverhead := int64(math.Ceil(float64(alignedSize) / (1 - overhead)))
 		diskSizeConverted, err := utils.FormatBytes(sizeWithOverhead)
 		if err != nil {
 			return dvs, err
@@ -798,7 +801,9 @@ func (o *OvirtMapper) mapFeatures() *kubevirtv1.Features {
 }
 
 func (o *OvirtMapper) mapTimeZone() *kubevirtv1.Clock {
+	clock := kubevirtv1.Clock{Timer: &kubevirtv1.Timer{}}
 	offset := kubevirtv1.ClockOffsetUTC{}
+
 	if tz, ok := o.vm.TimeZone(); ok {
 		if utcOffset, ok := tz.UtcOffset(); ok {
 			parsedOffset, err := utils.ParseUtcOffsetToSeconds(utcOffset)
@@ -807,10 +812,15 @@ func (o *OvirtMapper) mapTimeZone() *kubevirtv1.Clock {
 			} else {
 				log.Info("VM's utc offset is malformed: " + err.Error())
 			}
+		} else if tzName, ok := tz.Name(); ok {
+			timezone := kubevirtv1.ClockOffsetTimezone(tzName)
+			clock.Timezone = &timezone
 		}
 	}
-	clock := kubevirtv1.Clock{Timer: &kubevirtv1.Timer{}}
-	clock.UTC = &offset
+
+	if clock.Timezone == nil {
+		clock.UTC = &offset
+	}
 
 	return &clock
 }
@@ -825,6 +835,7 @@ func getDiskAttachmentByID(id string, diskAttachments *ovirtsdk.DiskAttachmentSl
 }
 
 func buildDataVolumeName(targetVMName string, diskAttachID string) string {
-	dvName, _ := utils.NormalizeName(targetVMName + "-" + diskAttachID)
-	return dvName
+	sha := sha1.New()
+	sha.Write([]byte(targetVMName + diskAttachID))
+	return fmt.Sprintf("%x", sha.Sum(nil))
 }
